#######################################################################
# RegressionModel.R
#
# This script runs through an example regression analysis
#
# Depends on: ipomopsis.txt
#
# created 11/1/2010 by M. Frazier
#
# last modified: 7/2/2014
#            by: A. Michelle Lawing
#
# More detailed description if necessary....
#######################################################################

setwd("/Users/michellelawing/Documents/RegressionExample") # set working directory
dir() # list files inside directory

ipomopsis<- read.table('http://www.unc.edu/courses/2007spring/enst/562/001/data/lab5/ipomopsis.txt', header=T,sep='\t')
#ipomopsis<- read.table("ipomopsis.txt", header=T,sep='\t') ## Alternative to read in data

head(ipomopsis) # first 6 rows of dataframe
dim(ipomopsis)  # dimensions: number of rows, columns
summary(ipomopsis) # summary
lapply(ipomopsis, class) # variable classes  

hist(ipomopsis$Root) #histogram
hist(ipomopsis$Fruit) #histogram

plot(ipomopsis$Grazing, ipomopsis$Root)
plot(ipomopsis$Grazing, ipomopsis$Fruit)

################################
## Plotting the point data
################################

plot(ipomopsis$Fruit ~ ipomopsis$Root,
     col=c("red", "blue")[ipomopsis$Grazing], #a little color coding
     pch=16) #pch is "point character" - it changes the type of point, pch=16 makes a filled circle (I use that one the most)

plot(ipomopsis$Fruit ~ ipomopsis$Root,
     col = c("red", "blue")[ipomopsis$Grazing], #a little color coding
     pch = 16,
     main = "Effects of grazing",
     ylab = "Fruit size (g)",
     xlab = "Root size (g)",
     las = 1, #las rotates the labels on the y axis
     cex = 1.5 #cex scales the point size up or down
     )
legend("topleft", legend=c("grazed", "ungrazed"), col=c("red", "blue"), pch=16)

###############################################################
## Linear models using ordinary least squares regression models
###############################################################

mod1 <- lm(Fruit ~ Root, data=ipomopsis) #### Here is the simplest possible model
plot(Fruit ~ Root, data=ipomopsis)
abline(mod1) #this plots the regression model on the figure
summary(mod1)

mod2 <- lm(Fruit ~ Root + Grazing, data=ipomopsis) #varying intercepts
plot(Fruit ~ Root, data=ipomopsis)
abline(mod2$coefficients[1], mod2$coefficients[2], col="red", lwd=2) # add line for the "grazed" category
abline((mod2$coefficients[1] + mod2$coefficients[3]), mod2$coefficients[2], col="blue", lwd=2) # add line for the "ungrazed" category
summary(mod2)

mod3 <- lm(Fruit ~ Root*Grazing, data=ipomopsis) ### Interaction effect
summary(mod3)

##############################
#### Model selection
##############################

AIC(mod1, mod2, mod3) #model selection

anova(mod1, mod2, mod3) #mod 2 is significantly better than mod1, mod 3 is NOT significantly better than mod2

###############################################################
## Peaking into the linear model
###############################################################

names(mod2) # here is a list of some of them

mod2$coefficients # they can be accessed like this

mod2$fitted.values # provides a predicted fruit size for each sample

mod2$residuals

plot(ipomopsis$Fruit, mod2$fitted.values) # compare the predicted and observed values

plot(mod2,which=1) # which tells the function which of the model assumptions plots to print, 1 is residuals vs. fitted values

plot(mod2,which=2) # 2 is Normal Q-Q plot

plot(mod2,which=3) # 3 is square root of standardized residuals

plot(mod2,which=4) # 4 is the influential residuals plot

confint(mod2)

